@@ -10,16 +10,16 @@ import rich.markdown
 import rich.box
 import rich.markup
 
-__version__ = "4.6.9"
+__version__ = "4.6.14"
 __ascii__ = False
 theme = rich.theme.Theme({
-    "echo": "bright_white",
+    "echo": "",
     "echo-bar": "",
-    "echo-pre": "dim bright_white",
+    "echo-pre": "dim",
     "echo-indent": "dim",
     "info": "",
-    "info-bar": "",
-    "info-pre": "dim",
+    "info-bar": "bright_white",
+    "info-pre": "dim bright_white",
     "info-indent": "dim",
     "warn": "red",
     "warn-bar": "red",
@@ -229,7 +229,7 @@ def get_input(question: str = "", prompt: str = "> ", default: str = "", strip:
     return answer
 
 
-def get_choice(choices, exitable: bool = False) -> str:
+def get_choice(choices, exitable: bool = False, default: str = "") -> str:
     """Get user choice from a given list
 
     Args:
@@ -237,16 +237,16 @@ def get_choice(choices, exitable: bool = False) -> str:
         exitable: bool. Does `exit` is an option for user to select.
     """
     EXIT_WORD = "exit" if "0" in choices else "0"
-    DECO_WORD = "[dim]{}[/]".format("--" if __ascii__ else "──")
-    BAR_WORD = "|" if __ascii__ else "│"
+    DECO = f"[dim]{'--' if __ascii__ else '──'}[/]"
+    BAR = "|" if __ascii__ else "│"
     CMD_TEXT = "[{color}]{icon}[/] [choice-cmd]{text}[/]"
     EXIT_TEXT = CMD_TEXT.format(color="red", icon='~' if __ascii__ else '✗', text="EXIT")
     fill = max(len(EXIT_WORD), 2)
     for index, item in enumerate(choices, start=1):
-        console.print(f"{BAR_WORD} [choice-i]{index:>{fill}}[/][dim])[/] [white]{item}[/]")
+        console.print(f"{BAR} [choice-i]{index:>{fill}}[/][dim])[/] [white]{item}[/]")
     if exitable:
-        console.print(f"{BAR_WORD} [choice-i]{EXIT_WORD:>{fill}}[/][dim])[/] {DECO_WORD} {EXIT_TEXT} {DECO_WORD}")
-    user_choice = get_input().strip()
+        console.print(f"{BAR} [choice-i]{EXIT_WORD:>{fill}}[/][dim])[/] {DECO} {EXIT_TEXT} {DECO}")
+    user_choice = get_input(default=default).strip()
     if exitable and user_choice == EXIT_WORD:
         return ""
     if user_choice in choices:
@@ -256,7 +256,7 @@ def get_choice(choices, exitable: bool = False) -> str:
         if 0 <= index < len(choices):
             return choices[index]
     err("Please enter a valid choice.")
-    return get_choice(choices)
+    return get_choice(choices, exitable, default)
 
 
 def get_choices(choices, allable: bool = False, exitable: bool = False) -> list:
@@ -290,7 +290,7 @@ def get_choices(choices, allable: bool = False, exitable: bool = False) -> list:
         elif exitable:  # no user selection, but exitable is on.
             console.print(f"{BAR_WORD} [choice-i]{EXIT_WORD:>{fill}}[/][dim])[/] {DECO_WORD} {EXIT_TEXT} {DECO_WORD}")
         user_choice = get_input().strip()
-        if (user_choice == DONE_WORD or user_choice == EXIT_WORD):
+        if (user_choice == DONE_WORD or user_choice == EXIT_WORD or user_choice == ""):
             if exitable or len(user_choices) > 0:  # keep looping when not exitable and no user choices.
                 return user_choices
         if allable and user_choice == ALL_WORD:
